@@ -3,7 +3,6 @@
 
 #include <vector>
 
-//#define MAX_SIZE 30
 const int MAX_SIZE = 30;
 
 int set_size(const int& set);
@@ -16,6 +15,8 @@ int unary(const int& x);
 
 int set_union(const int& set1, const int& set2);
 
+bool is_subset(const int& subset, const int& set);
+
 // get non-empty subsets of a set of size n in order of cardinality (banker's sequence)
 std::vector<int> get_subsets(const int &n);
 
